﻿--[[
NameViolation
last update: September 16, 2008
]]

function NameViolation_GetMessage(msgKey, ...)
    local msg = NAMEVIOLATION_MSG[msgKey];
    if (msg == nil) then
		return msgKey; -- treat msgKey as the message
    elseif (select('#', ...) > 0) then -- if any extra parameters
		return string.format(msg, ...);
	else
		return msg;
    end
end

function NameViolation_Message(msgKey, ...)
    local msg = NameViolation_GetMessage(msgKey, ...);
    if (DEFAULT_CHAT_FRAME) then
		DEFAULT_CHAT_FRAME:AddMessage(msg, 1, 1, 0);
    end
end

-- used for parsing slash commands
function NameViolation_ParseCommand(msg)
	if (msg == nil or msg == "") then
		return "";
	else
		local s,e,cmd = string.find(msg, "(%S+)"); -- contiguous non-space characters
		if (s) then
			return cmd, strsub(msg, e+2);
		else
			return "";
		end
	end
end

function NameViolation_GetTooltip()
	NameViolationScanningTooltip:ClearLines();
	NameViolationScanningTooltip:SetUnit("target");
	return NameViolationScanningTooltipTextLeft2:GetText();
end

function NameViolation_Exists(name)
	for i,v in ipairs(NameViolation_Names) do
		if (v[1] == name) then
			return i;
		end
	end
	return nil;
end

StaticPopupDialogs["NAMEVIOLATION_CONFIRMCLEAR"] = {
	text = NAMEVIOLATION_CONFIRM_DELETE,
	button1 = YES; -- global strings
	button2 = NO; -- global strings
	timeout = 0,
	whileDead = 1,
	OnAccept = function() 
		NameViolation_Names = { }
		NameViolation_Message("CLEARED")
	end
}



StaticPopupDialogs["NAMEVIOLATION_CONFIRMCLEAR_REPORTED"] = {
	text = NAMEVIOLATION_CONFIRM_DELETE_REPORTED,
	button1 = YES; -- global strings
	button2 = NO; -- global strings
	timeout = 0,
	whileDead = 1,
	OnAccept = function()
		local reportText = HelpFrameOpenTicketText:GetText();
		local reportedNames = {};
		for i,v in ipairs(NameViolation_Names) do
			-- can't easily parse only names in window, so check if any saved names are in window
			if (string.find(reportText, string.gsub(v[1], "([%(%)])", "%%%1"))) then
				table.insert(reportedNames, v[1]);
			end
		end
		if (#reportedNames > 0) then
			-- delete reported names
			for i, name in ipairs(reportedNames) do
				local index = NameViolation_Exists(name);
				if (index) then
					table.remove(NameViolation_Names, index);
				end
			end
			NameViolation_Message("REPORTED");
		end
	end
}

StaticPopupDialogs["NAMEVIOLATION_CONFIRMRESET"] = {
	text = NAMEVIOLATION_CONFIRM_RESET,
	button1 = YES; -- global strings
	button2 = NO; -- global strings
	timeout = 0,
	whileDead = 1,
	OnAccept = function() 
		NameViolation_Names = { };
		NameViolation_ResetOptions();
		NameViolation_Message("RESET");
	end
}

function NameViolation_GetPopupMenuIndices(which)
	local ni, gi;
	for i=#UnitPopupMenus[which],1,-1 do
		if (UnitPopupMenus[which][i] == "NAME_VIOLATION" or UnitPopupMenus[which][i] == "PET_VIOLATION") then
			ni = i;
		elseif (UnitPopupMenus[which][i] == "GUILD_VIOLATION") then
			gi = i;
		end
		if (ni and gi) then break; end
	end
	return ni, gi;
end

function NameViolation_TargetIsPet()
	if (UnitExists("target") and UnitPowerType("target") == 2 and not UnitIsUnit("target", "pet")) then
		-- note that this returns false for the player's pet,
		-- and relies on the fact that only hunter pets have focus as power type
		return true;
	else
		return false;
	end
end

function IsRPServer()
	local RPServers = {
	
	-- US (22) --
	"Argent Dawn",
	"Blackwater Raiders",
	"Cenarion Circle",
	"Earthen Ring",
	"Emerald Dream",
	"Farstriders",
	"Feathermoon",
	"Kirin Tor",
	"Lightninghoof",
	"Maelstrom",
	"Moon Guard",
	"Ravenholdt",
	"Scarlet Crusade",
	"Shadow Council",
	"Silver Hand",
	"Sentinels",
	"Sisters of Elune",
	"Steamwheedle Cartel",
	"The Scryers",
	"The Venture Co",
	"Thorium Brotherhood",
	"Twisting Nether",
	
	-- Europe (34) --
	-- English --
	--Argent Dawn,
	"Darkmoon Faire",
	"Defias Brotherhood",
	--Earthen Ring,
	"Moonglade",
	--Ravenholdt,
	"Scarshield Legion",
	"Sporeggar",
	--Steamwheedle Cartel,
	"The Sha'tar",
	"The Venture Co.", -- note the period

	-- German --
	"Das Konsortium",
	"Das Syndikat",
	"Der abyssische Rat",
	"Der Mithrilorden",
	"Der Rat von Dalaran",
	"Die Aldor",
	"Die Arguswacht",
	"Die ewige Wacht",
	"Die Nachtwache",
	"Die Silberne Hand",
	"Die Todeskrallen",
	"Forscherliga",
	"Kult der Verdammten",
	"Todeswache",
	"Zirkel des Cenarius",

	-- French --
	"Confrerie du Thorium",
	"Conseil des Ombres",
	"Culte de la Rive noire",
	"Kirin Tor",
	"La Croisade ecarlate",
	"Les Clairvoyants",
	"Les Sentinelles",

	-- Spanish --
	"Los Errantes",
	"Shen'dralar"
	}

	if tContains(RPServers, GetRealmName()) then
		return true
	else
		return false
	end
end

-- for debug only
function out(msg)
	DEFAULT_CHAT_FRAME:AddMessage(tostring(msg), 1.0, 1.0, 1.0);
	UIErrorsFrame:AddMessage(tostring(msg), 1.0, 1.0, 1.0, 1, 0); 
end