--[[
NameViolation
last update: September 16, 2008
]]

function NameViolation_Options_Okay()
	-- save editboxes
	if (NameViolationOptionsReportSalutation:GetText() ~= NameViolation_Settings.ReportSalutation) then
		NameViolation_Settings.ReportSalutation = NameViolationOptionsReportSalutation:GetText();
	end
	if (NameViolationOptionsReportOpening:GetText() ~= NameViolation_Settings.ReportOpening) then
		NameViolation_Settings.ReportOpening = NameViolationOptionsReportOpening:GetText();
	end
	if (NameViolationOptionsReportClosing:GetText() ~= NameViolation_Settings.ReportClosing) then
		NameViolation_Settings.ReportClosing = NameViolationOptionsReportClosing:GetText();
	end	
	
	-- copy settings for next time
	for k,setting in pairs(NameViolation_Settings) do
		NameViolation_OriginalSettings[k] = setting;
	end
end

function NameViolation_Options_Cancel()
	-- restore settings
	for k,setting in pairs(NameViolation_OriginalSettings) do
		NameViolation_Settings[k] = setting;
	end
	NameViolation_Options_UpdatePopups();
end

function NameViolation_Options_Default(...)
	NameViolation_ResetOptions();
end

function NameViolation_Options_SetChecksEnabled(enabled)
	if (enabled) then
		NameViolationOptionsPetsCheck:Enable();
		NameViolationOptionsPetsCheckText:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b);
		NameViolationOptionsPartyCheck:Enable();
		NameViolationOptionsPartyCheckText:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b);
		NameViolationOptionsRaidCheck:Enable();
		NameViolationOptionsRaidCheckText:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b);
	else
		NameViolationOptionsPetsCheck:Disable();
		NameViolationOptionsPetsCheckText:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
		NameViolationOptionsPartyCheck:Disable();
		NameViolationOptionsPartyCheckText:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
		NameViolationOptionsRaidCheck:Disable();
		NameViolationOptionsRaidCheckText:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
	end
end

-- used on cancel or resetting options to default
function NameViolation_Options_UpdatePopups()
	NameViolation_Options_UpdateCategories();
	NameViolation_Options_UpdateTargetFrame("PLAYER"); -- takes care of all others
end

-- used when categories are toggled in options
function NameViolation_Options_UpdateCategories()
	local val;
	if (NameViolation_Settings.ShowCategories) then val = 1; else val = nil; end
	UnitPopupButtons["NAME_VIOLATION"]["nested"] = val;
	UnitPopupButtons["GUILD_VIOLATION"]["nested"] = val;
	UnitPopupButtons["PET_VIOLATION"]["nested"] = val;
end

-- used when guild button is toggled in options
-- add or remove guild buttons (only) as necessary
function NameViolation_Options_UpdateGuildNames()
	local add = NameViolation_Settings.Guilds;
	for i,e in ipairs({"PLAYER","PARTY","RAID_PLAYER"}) do
		local ni, gi = NameViolation_GetPopupMenuIndices(e);
		if (add) then
			if (ni and not gi) then
				-- add if name button is available, but no guild button yet
				table.insert(UnitPopupMenus[e], ni+1, "GUILD_VIOLATION");
			end
		else
			if (gi) then
				table.remove(UnitPopupMenus[e], gi);
			end
		end
	end
end

-- used when pets button is toggled in options
-- add or remove pet button as necessary
function NameViolation_Options_UpdatePets()
	local pos = #UnitPopupMenus["PLAYER_PET"]-1;
	if (UnitPopupMenus["PLAYER_PET"][pos] == "PET_VIOLATION") then
		if ( not (NameViolation_Settings.PetPopup and NameViolation_Settings.TargetPopup) ) then
			table.remove(UnitPopupMenus["PLAYER_PET"], pos);
		end
	else
		if (NameViolation_Settings.PetPopup and NameViolation_Settings.TargetPopup) then
			table.insert(UnitPopupMenus["PLAYER_PET"], pos+1, "PET_VIOLATION");
		end
	end
end

-- add/remove popup buttons when target, party or raid are toggled in options
-- PLAYER = other players (target frame only)
-- PARTY = party members (party or target frame)
-- RAID_PLAYER = raid members (target frame only)
function NameViolation_Options_UpdateTargetFrame(which)
	local setting;
	if (which == "PARTY") then
		setting = NameViolation_Settings.PartyPopup;
	elseif (which == "RAID_PLAYER") then
		setting = NameViolation_Settings.RaidPopup;
	else -- must be PLAYER
		setting = true; -- only need to check TargetPopup
	end
	local ni, gi = NameViolation_GetPopupMenuIndices(which);
	if (ni) then
		if ( not (setting and NameViolation_Settings.TargetPopup) ) then
			-- remove buttons
			if (gi) then
				table.remove(UnitPopupMenus[which], gi);
			end
			table.remove(UnitPopupMenus[which], ni);
		end
	else
		if (setting and NameViolation_Settings.TargetPopup) then
			-- add button
			local pos = #UnitPopupMenus[which];
			table.insert(UnitPopupMenus[which], pos, "NAME_VIOLATION");
			if (not gi and NameViolation_Settings.Guilds) then
				table.insert(UnitPopupMenus[which], pos+1, "GUILD_VIOLATION");
			end
		end
	end
	if (which == "PLAYER") then
		-- others depend on this
		NameViolation_Options_UpdateTargetFrame("PARTY");
		NameViolation_Options_UpdateTargetFrame("RAID_PLAYER");
		NameViolation_Options_UpdatePets();
	end
end

