--[[
NameViolation
last update: Sept 16, 2008
]]

NameViolationReportMessage = "";

function NameViolationReport_OnLoad()
	table.insert(UISpecialFrames,"NameViolationReportFrame") -- allow hitting ESC to close
end

-- show message
function NameViolationReport_OnShow()
	local report = NameViolation_GetReportMessage()
	if (report ~= "") then
		NameViolationReportMessage = report; -- used to reset message if edited by user
		NameViolationReportEditBox:SetText(report)
		NameViolationReportEditBox:SetFocus()
		NameViolationReportFrame:SetWidth(350) 
		NameViolationReportEditBox:SetWidth(NameViolationReportFrame:GetWidth()-50)
		NameViolationReportFrame:SetHeight(HelpFrame:GetHeight()-12)
		HelpFrame:ClearAllPoints() 
		HelpFrame:SetPoint("CENTER", UIParent, "CENTER", NameViolationReportFrame:GetWidth()/2, 0);
		NameViolationReportFrame:ClearAllPoints()
		NameViolationReportFrame:SetPoint("RIGHT", HelpFrame, "LEFT", 15, 5);
	end
end

-- saves page when window hides
function NameViolationReport_OnHide()
	NameViolationReportEditBox:ClearFocus()
	if (HelpFrameOpenTicket:IsVisible()) then
		HelpFrame:ClearAllPoints() 
		HelpFrame:SetPoint("CENTER", UIParent, "CENTER");
	end
end

function NameViolationReport_OnTextChanged()
	-- not ideal, but can't disable keyboard because then copy paste isn't possible
	if (this:GetText() ~= NameViolationReportMessage) then
		this:SetText(NameViolationReportMessage);
	end
	local scrollBar = getglobal(this:GetParent():GetName().."ScrollBar")
	this:GetParent():UpdateScrollChildRect()
	local min, max = scrollBar:GetMinMaxValues()
	if ( max > 0 and (this.max ~= max) ) then
		this.max = max
		scrollBar:SetValue(max)
	end
end

--[[
this maximum is in place per GM request:
see http://forums.worldofwarcraft.com/thread.html?topicId=5784380534&postId=57836907667
increasing it to allow reporting many names at once is not recommended, as it
can be frustrating for GMs and may mean they aren't able to consider all of them
]]
NAMEVIOLATION_MAX_NAMES = 8;

function NameViolation_GetReportMessage()

	local intro = "";
	if (NameViolation_Settings.ReportSalutation ~= "") then
		intro = NameViolation_Settings.ReportSalutation .. "\n\n";
	end
	if (NameViolation_Settings.ReportOpening ~= "") then
		intro = intro .. NameViolation_Settings.ReportOpening .. "\n\n";
	end
	
	local ending = "";
	if (NameViolation_Settings.ReportClosing ~= "") then
		ending = "\n"..NameViolation_Settings.ReportClosing;
	end
	ending =  ending .. "\n" .. UnitName("player") .. " (" .. GetRealmName() .. ")";
	-- realm name is important to mention, especially when in battlegrounds (GMs won't know, apparently)
	
	local charsLeft = 500 - string.len(intro..ending);
	
	local msg = intro;
	
	local count = 0;
	if (#NameViolation_Names > 0) then
		for i,v in ipairs(NameViolation_Names) do
		
			if (count < NAMEVIOLATION_MAX_NAMES) then
				local name = v[1]
				local category = v[2]
				line = " * " .. name;
				if (category) then
					line = line .. " [" .. category .. "]";
				end
				line = line .. "\n";
				if (charsLeft >= string.len(line)) then
					charsLeft = charsLeft - string.len(line);
					msg = msg .. line;
					count = count + 1;
				else
					NameViolation_Message("TOO_LONG", count);
					break;
				end
			else
				NameViolation_Message("TOO_MANY", NAMEVIOLATION_MAX_NAMES);
				break;
			end
		end
	else
		msg = msg .. NAMEVIOLATION_REPORT_NONAMES .. "\n";
	end
		
	msg = msg .. ending;
	return msg;
end

-- when submitting ticket, close name violation window too and record names
local NameViolation_TicketSubmitHook = function(...)
	if (NameViolationReportFrame:IsVisible()) then
		-- close pad if open
		NameViolationReportFrame:Hide();
	end
	local reportText = HelpFrameOpenTicketText:GetText();
	if ( HelpFrame.needResponse == false	and string.find(reportText, NAMEVIOLATION_KEY) ) then 
		-- must be name violation report
		NameViolation_Message("TICKET_NEW");
		-- prompt user about deleting reported names
		StaticPopup_Show("NAMEVIOLATION_CONFIRMCLEAR_REPORTED");
	end
end
hooksecurefunc("HelpFrameOpenTicketSubmit_OnClick", NameViolation_TicketSubmitHook);

-- when cancelling ticket, close name violation window too
local NameViolation_TicketCancelHook = function(...)
	if (NameViolationReportFrame:IsVisible()) then
		-- close pad if open
		NameViolationReportFrame:Hide();
	end
end
hooksecurefunc("HelpFrameOpenTicketCancel_OnClick", NameViolation_TicketCancelHook);
